@@ -55,12 +55,15 @@ class KNativeKafkaProducer(threading.Thread):
        
         self.producer = KafkaProducer(bootstrap_servers=self.bootstrap_servers,
                         security_protocol=self.security_protocol,
+                        ssl_check_hostname=True,
                         ssl_cafile=self.ssl_cafile,
                         ssl_certfile=self.ssl_certfile,
-                        ssl_keyfile=self.ssl_keyfile
-                        )
+                        ssl_keyfile=self.ssl_keyfile,
+                        api_version=(2,0,0))
+                            
+                   
 
-    def send_binary_data(self, data:str, key:str):
+    def send_data_and_key(self, data:str, key:str):
         """
         Sends the binary data to Kafka topic using the send()
         Parameters
@@ -77,6 +80,24 @@ class KNativeKafkaProducer(threading.Thread):
             self.logger.error(f'Kafka Error {e}')
             raise Exception(f'Kafka Error {e}')
 
+    
+    def send_binary_data(self, data:str):
+        """
+        Sends the binary data to Kafka topic using the send()
+        Parameters
+        ----------
+            :param self: KNativeKafkaProducer object
+            :param data: A string representing a binary message 
+        """
+        try:
+            self.logger.info('Sending the data {} to topic {}'.format(data, self.topic))
+            self.producer.send(self.topic, data)
+            self.producer.flush(30)
+        except KafkaError as e:
+            self.logger.error(f'Kafka Error {e}')
+            raise Exception(f'Kafka Error {e}')
+
+
     def flush(self):
         if self.producer: 
             self.producer.flush()
